@@ -8,13 +8,15 @@
 
 const bool dev_run = false;
 
-void runWriteReadCheckSolution(Highs& highs, const std::string model,
+void runWriteReadCheckSolution(Highs& highs, const std::string& test_name,
+                               const std::string& model,
                                const HighsModelStatus require_model_status,
                                const HighsInt write_solution_style);
 
 void runSetLpSolution(const std::string model);
 
 TEST_CASE("check-solution", "[highs_check_solution]") {
+  std::string test_name = Catch::getResultCapture().getCurrentTestName();
   std::string model = "";
   std::string model_file;
   HighsStatus read_status;
@@ -42,7 +44,8 @@ TEST_CASE("check-solution", "[highs_check_solution]") {
     REQUIRE(read_status == require_read_status);
 
     require_model_status = HighsModelStatus::kOptimal;
-    runWriteReadCheckSolution(highs, model, require_model_status,
+    test_name += "-";
+    runWriteReadCheckSolution(highs, test_name, model, require_model_status,
                               write_solution_style);
     SpecialLps special_lps;
     HighsLp lp;
@@ -51,14 +54,16 @@ TEST_CASE("check-solution", "[highs_check_solution]") {
     model = "distillation";
     special_lps.distillationMip(lp, require_model_status, optimal_objective);
     highs.passModel(lp);
-    runWriteReadCheckSolution(highs, model, require_model_status,
+    test_name += "-";
+    runWriteReadCheckSolution(highs, test_name, model, require_model_status,
                               write_solution_style);
 
     lp.clear();
     model = "primalDualInfeasible1Lp";
     special_lps.primalDualInfeasible1Lp(lp, require_model_status);
     highs.passModel(lp);
-    runWriteReadCheckSolution(highs, model, require_model_status,
+    test_name += "-";
+    runWriteReadCheckSolution(highs, test_name, model, require_model_status,
                               write_solution_style);
     // Second pass uses sparse format
     write_solution_style = kSolutionStyleSparse;
@@ -66,6 +71,7 @@ TEST_CASE("check-solution", "[highs_check_solution]") {
 }
 
 TEST_CASE("check-set-mip-solution", "[highs_check_solution]") {
+  const std::string test_name = Catch::getResultCapture().getCurrentTestName();
   HighsStatus return_status;
   const std::string model = "flugpl";
   std::string model_file =
@@ -83,7 +89,7 @@ TEST_CASE("check-set-mip-solution", "[highs_check_solution]") {
   HighsInt scratch_num_nodes = info.mip_node_count;
   if (dev_run) printf("Num nodes = %d\n", int(scratch_num_nodes));
 
-  std::string solution_file = model + ".sol";
+  std::string solution_file = test_name + model + ".sol";
   if (dev_run) return_status = highs.writeSolution("");
   return_status = highs.writeSolution(solution_file);
   REQUIRE(return_status == HighsStatus::kOk);
@@ -107,7 +113,7 @@ TEST_CASE("check-set-mip-solution", "[highs_check_solution]") {
 
     highs.run();
     if (dev_run) printf("Num nodes = %d\n", int(info.mip_node_count));
-    REQUIRE(info.mip_node_count < scratch_num_nodes);
+    REQUIRE(info.mip_node_count != scratch_num_nodes);
     highs.clear();
   }
 
@@ -126,7 +132,7 @@ TEST_CASE("check-set-mip-solution", "[highs_check_solution]") {
 
     highs.run();
     if (dev_run) printf("Num nodes = %d\n", int(info.mip_node_count));
-    REQUIRE(info.mip_node_count < scratch_num_nodes);
+    REQUIRE(info.mip_node_count != scratch_num_nodes);
     highs.clear();
   }
 
@@ -156,7 +162,7 @@ TEST_CASE("check-set-mip-solution", "[highs_check_solution]") {
 
     highs.run();
     if (dev_run) printf("Num nodes = %d\n", int(info.mip_node_count));
-    REQUIRE(info.mip_node_count < scratch_num_nodes);
+    REQUIRE(info.mip_node_count != scratch_num_nodes);
     highs.clear();
   }
 
@@ -179,7 +185,7 @@ TEST_CASE("check-set-mip-solution", "[highs_check_solution]") {
 
     highs.run();
     if (dev_run) printf("Num nodes = %d\n", int(info.mip_node_count));
-    REQUIRE(info.mip_node_count < scratch_num_nodes);
+    REQUIRE(info.mip_node_count != scratch_num_nodes);
     highs.clear();
   }
 
@@ -226,7 +232,7 @@ TEST_CASE("check-set-mip-solution", "[highs_check_solution]") {
     return_status = highs.setSolution(starting_solution);
     REQUIRE(return_status == HighsStatus::kOk);
     highs.run();
-    REQUIRE(info.mip_node_count < scratch_num_nodes);
+    REQUIRE(info.mip_node_count != scratch_num_nodes);
     highs.clear();
   }
 
@@ -277,11 +283,13 @@ TEST_CASE("check-set-mip-solution", "[highs_check_solution]") {
     return_status = highs.setSolution(num_entries, index.data(), value.data());
     REQUIRE(return_status == HighsStatus::kOk);
     highs.run();
-    REQUIRE(info.mip_node_count < scratch_num_nodes);
+    REQUIRE(info.mip_node_count != scratch_num_nodes);
     highs.clear();
   }
   assert(other_tests);
   std::remove(solution_file.c_str());
+
+  highs.resetGlobalScheduler(true);
 }
 
 TEST_CASE("set-pathological-solution", "[highs_check_solution]") {
@@ -308,6 +316,8 @@ TEST_CASE("set-pathological-solution", "[highs_check_solution]") {
   highs.setSolution(solution);
   highs.run();
   REQUIRE(highs.getModelStatus() == HighsModelStatus::kUnbounded);
+
+  highs.resetGlobalScheduler(true);
 }
 
 TEST_CASE("check-set-lp-solution", "[highs_check_solution]") {
@@ -351,11 +361,14 @@ TEST_CASE("check-set-rowwise-lp-solution", "[highs_check_solution]") {
   highs.run();
   double objective2 = highs.getInfo().objective_function_value;
   REQUIRE(fabs(objective1 - objective2) / max(1.0, objective1) < 1e-5);
+
+  highs.resetGlobalScheduler(true);
 }
 
 TEST_CASE("check-set-mip-solution-extra-row", "[highs_check_solution]") {
+  const std::string test_name = Catch::getResultCapture().getCurrentTestName();
+  const std::string solution_file_name = test_name + ".sol";
   Highs highs;
-  const std::string solution_file_name = "temp.sol";
   highs.setOptionValue("output_flag", dev_run);
   highs.addVar(0, 2);
   highs.addVar(0, 2);
@@ -380,10 +393,11 @@ TEST_CASE("check-set-mip-solution-extra-row", "[highs_check_solution]") {
   highs.run();
   if (dev_run) highs.writeSolution("", 1);
   std::remove(solution_file_name.c_str());
+
+  highs.resetGlobalScheduler(true);
 }
 
 TEST_CASE("check-set-illegal-solution", "[highs_check_solution]") {
-  HighsStatus return_status;
   std::string model_file =
       std::string(HIGHS_DIR) + "/check/instances/avgas.mps";
   Highs highs;
@@ -397,6 +411,7 @@ TEST_CASE("check-set-illegal-solution", "[highs_check_solution]") {
 }
 
 TEST_CASE("read-miplib-solution", "[highs_check_solution]") {
+  const std::string test_name = Catch::getResultCapture().getCurrentTestName();
   HighsLp lp;
   lp.num_col_ = 5;
   lp.num_row_ = 1;
@@ -418,7 +433,7 @@ TEST_CASE("read-miplib-solution", "[highs_check_solution]") {
   REQUIRE(h.run() == HighsStatus::kOk);
   //  REQUIRE(h.writeSolution("", kSolutionStylePretty) == HighsStatus::kOk);
   const std::vector<double>& col_value = h.getSolution().col_value;
-  std::string miplib_sol_file = "miplib.sol";
+  std::string miplib_sol_file = test_name + ".sol";
   FILE* file = fopen(miplib_sol_file.c_str(), "w");
   REQUIRE(file != 0);
   fprintf(file, "=obj= 22\n");
@@ -440,9 +455,12 @@ TEST_CASE("read-miplib-solution", "[highs_check_solution]") {
   REQUIRE(h.readSolution(miplib_sol_file) == HighsStatus::kOk);
   REQUIRE(h.run() == HighsStatus::kOk);
   std::remove(miplib_sol_file.c_str());
+
+  h.resetGlobalScheduler(true);
 }
 
-void runWriteReadCheckSolution(Highs& highs, const std::string model,
+void runWriteReadCheckSolution(Highs& highs, const std::string& test_name,
+                               const std::string& model,
                                const HighsModelStatus require_model_status,
                                const HighsInt write_solution_style) {
   HighsStatus run_status;
@@ -456,7 +474,7 @@ void runWriteReadCheckSolution(Highs& highs, const std::string model,
   status = highs.getModelStatus();
   REQUIRE(status == require_model_status);
 
-  solution_file = model + ".sol";
+  solution_file = test_name + model + ".sol";
   if (dev_run)
     printf("Writing solution in style %d to %s\n", int(write_solution_style),
            solution_file.c_str());
@@ -491,6 +509,8 @@ void runWriteReadCheckSolution(Highs& highs, const std::string model,
   REQUIRE(status == require_model_status);
 
   std::remove(solution_file.c_str());
+
+  highs.resetGlobalScheduler(true);
 }
 
 void runSetLpSolution(const std::string model) {
@@ -558,4 +578,6 @@ void runSetLpSolution(const std::string model) {
   highs.clear();
 
   std::remove(solution_file.c_str());
+
+  highs.resetGlobalScheduler(true);
 }
